All Classes Interface Summary Class Summary Enum Summary Exception Summary Annotation Types Summary
| Class |
Description |
| Activation |
An object which allows to bind names to values.
|
| AdaptingTypes |
Collection of types which support bidirectional adaptation between CEL and Java native value
representations.
|
| AstMutator |
|
| AstMutator.MangledComprehensionAst |
Intermediate value class to store the mangled identifiers for iteration variable and the
comprehension result.
|
| AstMutator.MangledComprehensionName |
Intermediate value class to store the mangled names for iteration variable and the
comprehension result.
|
| AstMutator.MangledComprehensionType |
Intermediate value class to store the types for iter_var and comprehension result of which its
identifier names are being mangled.
|
| BasicCodePointArray |
An array of code points that contain code points from both the Latin-1 character set and Basic
Multilingual Plane.
|
| BidiConverter<A,B> |
The BidiConverter is a bidirectional converter which contains Converter objects
to forward convert from proto to CEL and backward convert from CEL to proto.
|
| BoolValue |
BoolValue is a simple CelValue wrapper around Java booleans.
|
| BytesValue |
BytesValue is a simple CelValue wrapper around CelByteString (immutable byte string).
|
| Cel |
Cel interface for parse, type-check, and evaluation of CEL programs.
|
| CelAbstractSyntaxTree |
Represents a checked or unchecked expression, its source, and related metadata such as source
position information.
|
| CelAstOptimizer |
Public interface for performing a single, custom optimization on an AST.
|
| CelAstOptimizer.OptimizationResult |
Denotes the result of a single optimization pass on an AST.
|
| CelAstValidator |
Public interface for performing a single, custom validation on an AST.
|
| CelAstValidator.IssuesFactory |
Factory for populating issues while performing AST validation.
|
| CelAttribute |
CelAttribute represents the select path from the root (.) to a single leaf value that may be
derived from the activation (e.g.
|
| CelAttribute.Qualifier |
Representation of a single select qualifier or index.
|
| CelAttribute.Qualifier.Kind |
Legal attribute qualifier kinds.
|
| CelAttributePattern |
|
| CelAttributeResolver |
Resolver for attribute lookups at runtime.
|
| CELBaseVisitor<T> |
This class provides an empty implementation of CELVisitor,
which can be extended to create a visitor which only needs to handle a subset
of the available methods.
|
| CelBuilder |
Interface for building an instance of Cel.
|
| CelByteString |
CelByteString is an immutable sequence of a byte array.
|
| CelChecker |
Public interface for type-checking parsed CEL expressions.
|
| CelCheckerBuilder |
Interface for building an instance of CelChecker
|
| CelCheckerLegacyImpl |
CelChecker implementation which uses the original CEL-Java APIs to provide a simple,
consistent interface for type-checking.
|
| CelCheckerLegacyImpl.Builder |
Builder class for the legacy CelChecker implementation.
|
| CelCheckerLibrary |
CelCheckerLibrary defines the interface to extend functionalities beyond the CEL standard
functions for CelChecker.
|
| CelCodePointArray |
Represents an in-memory read-only contiguous source of Unicode code points.
|
| CelCompiler |
CelCompiler bundles up the common concerns for parsing and type-checking exposes additional
methods for performing both operations in a single pass.
|
| CelCompilerBuilder |
Interface for building an instance of CelCompiler
|
| CelCompilerFactory |
Factory class for creating builders for type-checker and compiler instances.
|
| CelCompilerImpl |
CelCompiler implementation which uses either the legacy or modernized CEL-Java stack to offer a
stream-lined expression parse/type-check experience, via a single compile method.
|
| CelCompilerImpl.Builder |
Builder for CelCompilerImpl
|
| CelCompilerLibrary |
CelCompilerLibrary defines the interface to extend functionalities beyond the CEL standard
functions for CelCompiler.
|
| CelConstant |
Represents a primitive literal.
|
| CelConstant.CelConstantNotSet |
An unset constant.
|
| CelConstant.Kind |
Represents the type of the Constant
|
| CelDescriptorPool |
CelDescriptorPool allows lookup of descriptors for message types and field descriptors
for Proto2 extension messages.
|
| CelDescriptors |
Value object containing multiple set of descriptors to be provided into the CEL environment.
|
| CelDescriptors.Builder |
Builder for configuring the CelDescriptors
|
| CelDescriptorUtil |
Utility class for working with protobuf descriptors.
|
| CelEncoderExtensions |
Internal implementation of Encoder Extensions.
|
| CelErrorCode |
The canonical error codes for CEL
|
| CelEvaluationException |
CelEvaluationException encapsulates the potential issues which could arise during the
configuration or evaluation of an expression Program.
|
| CelEvaluationListener |
Functional interface for a callback method invoked by the runtime.
|
| CelException |
Base class for all checked exceptions explicitly thrown by the library.
|
| CelExpr |
An abstract representation of a common expression.
|
| CelExpr.Builder |
Builder for CelExpr.
|
| CelExpr.CelCall |
A call expression.
|
| CelExpr.CelCall.Builder |
Builder for CelCall.
|
| CelExpr.CelComprehension |
A comprehension expression applied to a list or map.
|
| CelExpr.CelComprehension.Builder |
Builder for Comprehension.
|
| CelExpr.CelIdent |
An identifier expression.
|
| CelExpr.CelIdent.Builder |
Builder for CelIdent.
|
| CelExpr.CelList |
A list creation expression.
|
| CelExpr.CelList.Builder |
Builder for CelList.
|
| CelExpr.CelMap |
A map creation expression.
|
| CelExpr.CelMap.Builder |
Builder for CelMap.
|
| CelExpr.CelMap.Entry |
Represents an entry of the map.
|
| CelExpr.CelMap.Entry.Builder |
Builder for CelMap.Entry.
|
| CelExpr.CelNotSet |
An unset expression.
|
| CelExpr.CelSelect |
A field selection expression.
|
| CelExpr.CelSelect.Builder |
Builder for CelSelect.
|
| CelExpr.CelStruct |
A message creation expression.
|
| CelExpr.CelStruct.Builder |
Builder for CelStruct.
|
| CelExpr.CelStruct.Entry |
Represents an entry of the struct
|
| CelExpr.CelStruct.Entry.Builder |
Builder for CelStruct.Entry.
|
| CelExpr.ExprKind |
Denotes the kind of the expression.
|
| CelExpr.ExprKind.Kind |
Expression kind.
|
| CelExprConverter |
Converts a proto-based Canonical Expression Tree Expr into the CEL native representation
of Expression tree CelExpr and vice versa.
|
| CelExprFactory |
Factory for generating expression nodes.
|
| CelExprIdGeneratorFactory |
Factory for populating expression IDs
|
| CelExprIdGeneratorFactory.ExprIdGenerator |
Functional interface for generating the next unique expression ID.
|
| CelExprIdGeneratorFactory.MonotonicIdGenerator |
MonotonicIdGenerator increments expression IDs from an initial seed value.
|
| CelExprIdGeneratorFactory.StableIdGenerator |
StableIdGenerator ensures new IDs are only created the first time they are encountered.
|
| CelExprV1Alpha1Converter |
Converts a proto-based Canonical Expression Tree Expr into the CEL native representation
of Expression tree CelExpr and vice versa.
|
| CelExprVisitor |
CEL expression visitor implementation using Cel native types.
|
| CelExprVisitor.ComprehensionArg |
ComprehensionArg specifies the arg ordinal values for comprehension arguments, where the
ordinal of the enum maps to the ordinal of the argument in the comprehension expression.
|
| CelExtensions |
Collections of CEL Extensions.
|
| CelFactory |
Helper class to configure the entire CEL stack in a common interface.
|
| CelFunctionDecl |
Abstract representation of a CEL Function declaration.
|
| CelFunctionDecl.Builder |
|
| CelFunctionOverload |
Interface describing the general signature of all CEL custom function implementations.
|
| CelFunctionOverload.Binary<T1,T2> |
Helper interface for describing binary functions where the type parameters are used to improve
compile-time correctness of function bindings.
|
| CelFunctionOverload.Unary<T> |
Helper interface for describing unary functions where the type-parameter is used to improve
compile-time correctness of function bindings.
|
| CelFunctionResolver |
Interface to a resolver for CEL functions based on the function name, overload ids, and
arguments.
|
| CelIdentDecl |
Abstract representation of a CEL identifier declaration.
|
| CelIdentDecl.Builder |
|
| CelIssue |
Encapulates a CelSourceLocation and message representing an error within an expression.
|
| CelIssue.Builder |
|
| CelIssue.Severity |
Severity of a CelIssue.
|
| CelKind |
The CelKind indicates the type category.
|
| CelLateFunctionBindings |
Collection of CelFunctionBinding values which are intended to be created once
per-evaluation, rather than once per-program setup.
|
| CELLexer |
|
| CelMacro |
|
| CelMacroExpander |
Converts the target and arguments of a function call that matches a macro.
|
| CelMacroExprFactory |
Assists with the expansion of CelMacro in a manner which is consistent with the source
position and expression ID generation code leveraged by both the parser and type-checker.
|
| CelMutableAst |
An abstract representation of CEL Abstract Syntax tree that allows mutation in any of its
properties.
|
| CelMutableExpr |
An abstract representation of a common expression that allows mutation in any of its properties.
|
| CelMutableExpr.CelMutableCall |
A mutable call expression.
|
| CelMutableExpr.CelMutableComprehension |
A mutable comprehension expression applied to a list or map.
|
| CelMutableExpr.CelMutableIdent |
A mutable identifier expression.
|
| CelMutableExpr.CelMutableList |
A mutable list creation expression.
|
| CelMutableExpr.CelMutableMap |
A mutable map creation expression.
|
| CelMutableExpr.CelMutableMap.Entry |
Represents an entry of the map
|
| CelMutableExpr.CelMutableSelect |
A mutable field selection expression.
|
| CelMutableExpr.CelMutableStruct |
A mutable list creation expression.
|
| CelMutableExpr.CelMutableStruct.Entry |
Represents a mutable entry of the struct.
|
| CelMutableExprConverter |
Converts a mutable Expression Tree CelMutableExpr into the CEL native representation of
Expression tree CelExpr and vice versa.
|
| CelMutableSource |
Represents the mutable portion of the CelSource.
|
| CelNavigableAst |
|
| CelNavigableExpr |
CelNavigableExpr decorates CelExpr with capabilities to inspect the parent and its
descendants with ease.
|
| CelNavigableExpr.Builder |
|
| CelNavigableMutableAst |
|
| CelNavigableMutableExpr |
CelNavigableMutableExpr decorates CelMutableExpr with capabilities to inspect the parent
and its descendants with ease.
|
| CelNavigableMutableExpr.Builder |
|
| CelOptimizationException |
Checked exception thrown by CelOptimizer during AST optimization.
|
| CelOptimizer |
Public interface for optimizing an AST.
|
| CelOptimizerBuilder |
Interface for building an instance of CelOptimizer.
|
| CelOptimizerFactory |
|
| CelOptionalLibrary |
Internal implementation of CEL optional values.
|
| CelOptionalLibrary.Function |
Enumerations of function names used for supporting optionals.
|
| CelOptions |
Options to configure how the CEL parser, type-checker, and evaluator behave.
|
| CelOptions.Builder |
Builder for configuring the CelOptions.
|
| CelOptions.ProtoUnsetFieldOptions |
ProtoUnsetFieldOptions describes how to handle Activation.fromProto() calls where proto message
fields may be unset and should either be handled perhaps as absent or as the default proto
value.
|
| CelOverloadDecl |
Abstract representation of a CEL function overload declaration.
|
| CelOverloadDecl.Builder |
|
| CelParser |
Public interface for the parsing CEL expressions.
|
| CELParser |
|
| CELParser.BoolFalseContext |
|
| CELParser.BoolTrueContext |
|
| CELParser.BytesContext |
|
| CELParser.CalcContext |
|
| CELParser.ConditionalAndContext |
|
| CELParser.ConditionalOrContext |
|
| CELParser.ConstantLiteralContext |
|
| CELParser.CreateListContext |
|
| CELParser.CreateMapContext |
|
| CELParser.CreateMessageContext |
|
| CELParser.DoubleContext |
|
| CELParser.ExprContext |
|
| CELParser.ExprListContext |
|
| CELParser.FieldInitializerListContext |
|
| CELParser.IdentOrGlobalCallContext |
|
| CELParser.IndexContext |
|
| CELParser.IntContext |
|
| CELParser.ListInitContext |
|
| CELParser.LiteralContext |
|
| CELParser.LogicalNotContext |
|
| CELParser.MapInitializerListContext |
|
| CELParser.MemberCallContext |
|
| CELParser.MemberContext |
|
| CELParser.MemberExprContext |
|
| CELParser.NegateContext |
|
| CELParser.NestedContext |
|
| CELParser.NullContext |
|
| CELParser.OptExprContext |
|
| CELParser.OptFieldContext |
|
| CELParser.PrimaryContext |
|
| CELParser.PrimaryExprContext |
|
| CELParser.RelationContext |
|
| CELParser.SelectContext |
|
| CELParser.StartContext |
|
| CELParser.StringContext |
|
| CELParser.UintContext |
|
| CELParser.UnaryContext |
|
| CelParserBuilder |
Interface for building an instance of CelParser
|
| CelParserFactory |
Factory class for producing CelParser instances and builders.
|
| CelParserImpl |
Modernized parser implementation for CEL.
|
| CelParserImpl.Builder |
|
| CelParserLibrary |
CelParserLibrary defines the interface to extend functionalities beyond the CEL standard
functions for CelParser.
|
| CelProtoAbstractSyntaxTree |
|
| CelProtoExprVisitor |
CEL expression visitor implementation based on the Expr proto.
|
| CelProtoJsonAdapter |
CelProtoJsonAdapter is a utility to handle conversion from Java native objects
representing CEL values to Protobuf's structured value which maps to JSON object schema.
|
| CelProtoTypes |
Utility class for working with Type.
|
| CelProtoV1Alpha1AbstractSyntaxTree |
|
| CelReference |
Describes a resolved reference to a declaration.
|
| CelReference.Builder |
|
| CelResolvedOverload |
Representation of a function overload which has been resolved to a specific set of argument types
and a function definition.
|
| CelRuntime |
The CelRuntime creates executable Program instances from CelAbstractSyntaxTree
values.
|
| CelRuntime.CelFunctionBinding |
Binding consisting of an overload id, a Java-native argument signature, and an overload
definition.
|
| CelRuntime.Program |
Creates an evaluable Program instance which is thread-safe and immutable.
|
| CelRuntimeBuilder |
Interface for building an instance of CelRuntime
|
| CelRuntimeException |
Wrapper for an unchecked runtime exception with a CelErrorCode supplied.
|
| CelRuntimeFactory |
Helper class to construct new CelRuntime instances.
|
| CelRuntimeLegacyImpl |
CelRuntime implementation based on the legacy CEL-Java stack.
|
| CelRuntimeLegacyImpl.Builder |
Builder class for CelRuntimeLegacyImpl.
|
| CelRuntimeLibrary |
CelCompilerLibrary defines the interface to extend functionalities beyond the CEL standard
functions for CelRuntime.
|
| CelSetsExtensions |
Internal implementation of CEL Set extensions.
|
| CelSetsExtensions.Function |
Denotes the set extension function.
|
| CelSource |
Represents the source content of an expression and related metadata.
|
| CelSource.Builder |
|
| CelSource.Extension |
Tag for an extension that were used while parsing or type checking the source expression.
|
| CelSource.Extension.Component |
CEL component specifier.
|
| CelSource.Extension.Version |
Version of the extension
|
| CelSourceHelper |
Helper methods for common source handling in CEL.
|
| CelSourceLocation |
|
| CelStandardDeclarations |
Standard declarations for CEL.
|
| CelStandardDeclarations.Builder |
Builder for constructing the set of standard function/identifiers.
|
| CelStandardDeclarations.Builder.FunctionFilter |
Functional interface for filtering standard functions.
|
| CelStandardDeclarations.Builder.IdentifierFilter |
Functional interface for filtering standard identifiers.
|
| CelStandardDeclarations.StandardIdentifier |
Standard CEL identifiers.
|
| CelStandardDeclarations.StandardOverload |
General interface for defining a standard function overload.
|
| CelStandardFunctions |
Runtime function bindings for the standard functions in CEL.
|
| CelStandardFunctions.Builder |
Builder for constructing the set of standard function/identifiers.
|
| CelStandardFunctions.Builder.FunctionFilter |
Functional interface for filtering standard functions.
|
| CelStandardFunctions.StandardFunction |
Enumeration of Standard Function bindings.
|
| CelStandardFunctions.StandardFunction.Overload |
Container class for CEL standard function overloads.
|
| CelStandardFunctions.StandardFunction.Overload.Arithmetic |
Overloads for performing arithmetic operations.
|
| CelStandardFunctions.StandardFunction.Overload.BooleanOperator |
Overloads for logical operators that return a bool as a result.
|
| CelStandardFunctions.StandardFunction.Overload.Comparison |
Overloads for performing numeric comparisons.
|
| CelStandardFunctions.StandardFunction.Overload.Conversions |
Overloads for performing type conversions.
|
| CelStandardFunctions.StandardFunction.Overload.DateTime |
Overloads for functions performing date/time operations.
|
| CelStandardFunctions.StandardFunction.Overload.Index |
Overloads for indexing a list or a map.
|
| CelStandardFunctions.StandardFunction.Overload.InternalOperator |
Overloads for internal functions that may have been rewritten by macros (ex: @in)
|
| CelStandardFunctions.StandardFunction.Overload.OptionalValue |
Overloads for optional values.
|
| CelStandardFunctions.StandardFunction.Overload.Relation |
Overloads for functions that test relations.
|
| CelStandardFunctions.StandardFunction.Overload.Size |
Overloads for retrieving the size of a literal or a collection.
|
| CelStandardFunctions.StandardFunction.Overload.StringMatchers |
Overloads for functions performing string matching, such as regular expressions or contains
check.
|
| CelStandardFunctions.StandardOverload |
General interface for defining a standard function overload.
|
| CelStandardMacro |
CelStandardMacro enum represents all of the macros defined as part of the CEL standard library.
|
| CelStringExtensions |
Internal implementation of CEL string extensions.
|
| CelStringExtensions.Function |
Denotes the string extension function
|
| CelType |
Abstract representation of a CEL type which indicates its CelKind, name, and
parameters.
|
| CelTypeProvider |
The CelTypeProvider is used to lookup CelType definitions by name, as well as
enumerate supported CelTypeProvider.types().
|
| CelTypeProvider.CombinedCelTypeProvider |
The CombinedCelTypeProvider implements the CelTypeProvider interface by merging
the CelType instances supported by each together.
|
| CelTypes |
Utility class for working with CelType.
|
| CelUnknownSet |
Unknown set representation.
|
| CelUnparser |
Provides an unparsing utility that converts an AST back into a human-readable format.
|
| CelUnparserFactory |
Factory class for producing CelUnparser instances and builders.
|
| CelUnparserVisitor |
Visitor implementation to unparse an AST.
|
| CelV1AlphaTypes |
Utility class for working with Type.
|
| CelValidationException |
Base class for all checked exceptions explicitly thrown by the library during parsing.
|
| CelValidationResult |
CelValidationResult encapsulates the CelAbstractSyntaxTree and CelIssue set which
may be generated during the parse and check phases.
|
| CelValidator |
Public interface for validating an AST.
|
| CelValidatorBuilder |
Interface for building an instance of CelValidator.
|
| CelValidatorFactory |
|
| CelValue |
A representation of a CEL value for the runtime.
|
| CelValueProvider |
CelValueProvider is an interface for constructing new struct values.
|
| CelValueProvider.CombinedCelValueProvider |
|
| CelVarDecl |
Abstract representation of a CEL variable declaration.
|
| CelVariableResolver |
Functional interface that exposes a method to find a CEL variable value by name.
|
| CELVisitor<T> |
This interface defines a complete generic visitor for a parse tree produced
by CELParser.
|
| CheckedExpr |
A CEL expression which has been successfully type checked.
|
| CheckedExpr |
A CEL expression which has been successfully type checked.
|
| CheckedExpr.Builder |
A CEL expression which has been successfully type checked.
|
| CheckedExpr.Builder |
A CEL expression which has been successfully type checked.
|
| CheckedExprOrBuilder |
|
| CheckedExprOrBuilder |
|
| CodePointStream |
Implementation of ANTLRv4 CharStream using CelCodePointArray.
|
| CombinedDescriptorPool |
|
| ComparisonFunctions |
The ComparisonFunctions methods provide safe cross-type comparisons between long,
double, and UnsignedLong values.
|
| Constant |
Represents a primitive literal.
|
| Constant |
Represents a primitive literal.
|
| Constant.Builder |
Represents a primitive literal.
|
| Constant.Builder |
Represents a primitive literal.
|
| Constant.ConstantKindCase |
|
| Constant.ConstantKindCase |
|
| ConstantFoldingOptimizer |
Performs optimization for inlining constant scalar and aggregate literal values within function
calls and select statements with their evaluated result.
|
| ConstantFoldingOptimizer.ConstantFoldingOptions |
Options to configure how Constant Folding behave.
|
| ConstantFoldingOptimizer.ConstantFoldingOptions.Builder |
|
| ConstantOrBuilder |
|
| ConstantOrBuilder |
|
| Constants |
Internal utility class for working with Constant.
|
| Converter<A,B> |
Functional interface for converting between two types.
|
| Decl |
Represents a declaration of a named value or function.
|
| Decl |
Represents a declaration of a named value or function.
|
| Decl.Builder |
Represents a declaration of a named value or function.
|
| Decl.Builder |
Represents a declaration of a named value or function.
|
| Decl.DeclKindCase |
|
| Decl.DeclKindCase |
|
| Decl.FunctionDecl |
Function declaration specifies one or more overloads which indicate the
function's parameter types and return type.
|
| Decl.FunctionDecl |
Function declaration specifies one or more overloads which indicate the
function's parameter types and return type.
|
| Decl.FunctionDecl.Builder |
Function declaration specifies one or more overloads which indicate the
function's parameter types and return type.
|
| Decl.FunctionDecl.Builder |
Function declaration specifies one or more overloads which indicate the
function's parameter types and return type.
|
| Decl.FunctionDecl.Overload |
An overload indicates a function's parameter types and return type, and
may optionally include a function body described in terms of
[Expr][google.api.expr.v1alpha1.Expr] values.
|
| Decl.FunctionDecl.Overload |
An overload indicates a function's parameter types and return type, and
may optionally include a function body described in terms of
[Expr][cel.expr.Expr] values.
|
| Decl.FunctionDecl.Overload.Builder |
An overload indicates a function's parameter types and return type, and
may optionally include a function body described in terms of
[Expr][google.api.expr.v1alpha1.Expr] values.
|
| Decl.FunctionDecl.Overload.Builder |
An overload indicates a function's parameter types and return type, and
may optionally include a function body described in terms of
[Expr][cel.expr.Expr] values.
|
| Decl.FunctionDecl.OverloadOrBuilder |
|
| Decl.FunctionDecl.OverloadOrBuilder |
|
| Decl.FunctionDeclOrBuilder |
|
| Decl.FunctionDeclOrBuilder |
|
| Decl.IdentDecl |
Identifier declaration which specifies its type and optional `Expr` value.
|
| Decl.IdentDecl |
Identifier declaration which specifies its type and optional `Expr` value.
|
| Decl.IdentDecl.Builder |
Identifier declaration which specifies its type and optional `Expr` value.
|
| Decl.IdentDecl.Builder |
Identifier declaration which specifies its type and optional `Expr` value.
|
| Decl.IdentDeclOrBuilder |
|
| Decl.IdentDeclOrBuilder |
|
| DeclOrBuilder |
|
| DeclOrBuilder |
|
| DeclProto |
|
| DeclProto |
|
| DefaultDescriptorPool |
A descriptor pool that has descriptors pre-loaded for well-known types defined by WellKnownProto.
|
| DefaultDispatcher |
|
| DefaultInstanceMessageFactory |
Singleton factory for creating default messages from a protobuf descriptor.
|
| DefaultInterpreter |
Default implementation of the CEL interpreter.
|
| DefaultMessageFactory |
DefaultMessageFactory produces Message.Builder instances by protobuf name.
|
| DefaultMetadata |
|
| DescriptorMessageProvider |
|
| DescriptorTypeProvider |
The DescriptorTypeProvider provides type information for one or more Descriptors.Descriptor
instances of proto messages.
|
| DescriptorTypeProvider.EnumValueDef |
|
| DescriptorTypeProvider.FieldDef |
Value object for a proto-based field definition.
|
| DescriptorTypeProvider.MapEntryDef |
Value object for Map entry TypeDef information.
|
| DescriptorTypeProvider.SymbolTable |
Helper class to construct a symbol table for messages, enums, and their respective
declarations.
|
| DescriptorTypeProvider.TypeDef |
Value object for a proto-based primitive, message, or enum definition.
|
| Dispatcher |
An object which implements dispatching of function calls.
|
| Dispatcher.ImmutableCopy |
|
| DoubleValue |
DoubleValue is a simple CelValue wrapper around Java doubles.
|
| DurationLiteralValidator |
DurationLiteralValidator ensures that duration literal arguments are valid.
|
| DurationValue |
DurationValue is a simple CelValue wrapper around Duration
|
| DynamicMessageFactory |
Deprecated.
|
| DynamicProto |
The DynamicProto class supports the conversion of Any values to concrete
Message types based on provided descriptors.
|
| EnumType |
Enum types to support strongly typed enums with lookups by value name and number.
|
| EnumType.EnumNameResolver |
Functional interface for looking up an enum name by its number.
|
| EnumType.EnumNumberResolver |
Functional interface for lookup up an enum number by its local or fully qualified name.
|
| EnumValue |
An enum value.
|
| EnumValue<E extends java.lang.Enum<E>> |
EnumValue is a simple CelValue wrapper around Java enums.
|
| EnumValue |
An enum value.
|
| EnumValue.Builder |
An enum value.
|
| EnumValue.Builder |
An enum value.
|
| EnumValueOrBuilder |
|
| EnumValueOrBuilder |
|
| Env |
Environment used during checking of expressions.
|
| Env.DeclGroup |
Object for managing a group of declarations within a scope.
|
| Env.FunctionBuilder |
Deprecated.
|
| Env.IdentBuilder |
Deprecated.
|
| EnvVisitable |
Simple API for exposing a class with a visitable CEL environment.
|
| EnvVisitor |
Simple API for visiting the declarations of a CEL environment
|
| Errors |
An object which manages error reporting.
|
| Errors.Error |
Represents an error.
|
| Errors.ErrorFormatter |
Helper interface to format an error string.
|
| Errors.SourceLocation |
SourceLocation gives the line and column where an expression starts.
|
| ErrorSet |
A set of errors.
|
| ErrorSet |
A set of errors.
|
| ErrorSet.Builder |
A set of errors.
|
| ErrorSet.Builder |
A set of errors.
|
| ErrorSetOrBuilder |
|
| ErrorSetOrBuilder |
|
| ErrorValue |
CelErrorValue represent the intermediate error that occurs during evaluation in the form of Java
exception.
|
| EvalProto |
|
| EvalProto |
|
| EvalState |
The state of an evaluation.
|
| EvalState |
The state of an evaluation.
|
| EvalState.Builder |
The state of an evaluation.
|
| EvalState.Builder |
The state of an evaluation.
|
| EvalState.Result |
A single evalution result.
|
| EvalState.Result |
A single evaluation result.
|
| EvalState.Result.Builder |
A single evalution result.
|
| EvalState.Result.Builder |
A single evaluation result.
|
| EvalState.ResultOrBuilder |
|
| EvalState.ResultOrBuilder |
|
| EvalStateOrBuilder |
|
| EvalStateOrBuilder |
|
| Explain |
Deprecated. |
| Explain |
Deprecated. |
| Explain.Builder |
Values of intermediate expressions produced when evaluating expression.
|
| Explain.Builder |
Values of intermediate expressions produced when evaluating expression.
|
| Explain.ExprStep |
ID and value index of one step.
|
| Explain.ExprStep |
ID and value index of one step.
|
| Explain.ExprStep.Builder |
ID and value index of one step.
|
| Explain.ExprStep.Builder |
ID and value index of one step.
|
| Explain.ExprStepOrBuilder |
|
| Explain.ExprStepOrBuilder |
|
| ExplainOrBuilder |
Deprecated. |
| ExplainOrBuilder |
Deprecated. |
| ExplainProto |
|
| ExplainProto |
|
| Expr |
An abstract representation of a common expression.
|
| Expr |
An abstract representation of a common expression.
|
| Expr.Builder |
An abstract representation of a common expression.
|
| Expr.Builder |
An abstract representation of a common expression.
|
| Expr.Call |
A call expression, including calls to predefined functions and operators.
|
| Expr.Call |
A call expression, including calls to predefined functions and operators.
|
| Expr.Call.Builder |
A call expression, including calls to predefined functions and operators.
|
| Expr.Call.Builder |
A call expression, including calls to predefined functions and operators.
|
| Expr.CallOrBuilder |
|
| Expr.CallOrBuilder |
|
| Expr.Comprehension |
A comprehension expression applied to a list or map.
|
| Expr.Comprehension |
A comprehension expression applied to a list or map.
|
| Expr.Comprehension.Builder |
A comprehension expression applied to a list or map.
|
| Expr.Comprehension.Builder |
A comprehension expression applied to a list or map.
|
| Expr.ComprehensionOrBuilder |
|
| Expr.ComprehensionOrBuilder |
|
| Expr.CreateList |
A list creation expression.
|
| Expr.CreateList |
A list creation expression.
|
| Expr.CreateList.Builder |
A list creation expression.
|
| Expr.CreateList.Builder |
A list creation expression.
|
| Expr.CreateListOrBuilder |
|
| Expr.CreateListOrBuilder |
|
| Expr.CreateStruct |
A map or message creation expression.
|
| Expr.CreateStruct |
A map or message creation expression.
|
| Expr.CreateStruct.Builder |
A map or message creation expression.
|
| Expr.CreateStruct.Builder |
A map or message creation expression.
|
| Expr.CreateStruct.Entry |
Represents an entry.
|
| Expr.CreateStruct.Entry |
Represents an entry.
|
| Expr.CreateStruct.Entry.Builder |
Represents an entry.
|
| Expr.CreateStruct.Entry.Builder |
Represents an entry.
|
| Expr.CreateStruct.Entry.KeyKindCase |
|
| Expr.CreateStruct.Entry.KeyKindCase |
|
| Expr.CreateStruct.EntryOrBuilder |
|
| Expr.CreateStruct.EntryOrBuilder |
|
| Expr.CreateStructOrBuilder |
|
| Expr.CreateStructOrBuilder |
|
| Expr.ExprKindCase |
|
| Expr.ExprKindCase |
|
| Expr.Ident |
An identifier expression.
|
| Expr.Ident |
An identifier expression.
|
| Expr.Ident.Builder |
An identifier expression.
|
| Expr.Ident.Builder |
An identifier expression.
|
| Expr.IdentOrBuilder |
|
| Expr.IdentOrBuilder |
|
| Expr.Select |
A field selection expression.
|
| Expr.Select |
A field selection expression.
|
| Expr.Select.Builder |
A field selection expression.
|
| Expr.Select.Builder |
A field selection expression.
|
| Expr.SelectOrBuilder |
|
| Expr.SelectOrBuilder |
|
| ExprChecker |
Deprecated.
|
| ExprChecker.OverloadResolution |
Helper object for holding an overload resolution result.
|
| Expression |
An abstract representation of a common expression.
|
| Expression.Call<E extends Expression> |
A call expression, including calls to predefined functions and operators.
|
| Expression.Comprehension<E extends Expression> |
A comprehension expression applied to a list or map.
|
| Expression.Ident |
An identifier expression.
|
| Expression.List<E extends Expression> |
A list creation expression.
|
| Expression.Map<E extends Expression.Map.Entry<?>> |
A map creation expression.
|
| Expression.Map.Entry<T extends Expression> |
Represents an entry of the map.
|
| Expression.Select<E extends Expression> |
A field selection expression.
|
| Expression.Struct<E extends Expression.Struct.Entry<?>> |
A message creation expression.
|
| Expression.Struct.Entry<T extends Expression> |
Represents an entry of the struct
|
| ExprFeatures |
Deprecated.
|
| ExprOrBuilder |
|
| ExprOrBuilder |
|
| ExprValue |
The value of an evaluated expression.
|
| ExprValue |
The value of an evaluated expression.
|
| ExprValue.Builder |
The value of an evaluated expression.
|
| ExprValue.Builder |
The value of an evaluated expression.
|
| ExprValue.KindCase |
|
| ExprValue.KindCase |
|
| ExprValueOrBuilder |
|
| ExprValueOrBuilder |
|
| ExprVisitor |
CEL expression visitor implementation.
|
| ExprVisitor.ComprehensionArg |
ComprehensionArg specifies the arg ordinal values for comprehension arguments, where the
ordinal of the enum maps to the ordinal of the argument in the comprehension expression.
|
| FileDescriptorSetConverter |
Utility class for converting from a FileDescriptorSet to a collection of
FileDescriptor instances.
|
| FunctionOverload |
Interface describing the general signature of all CEL custom function implementations.
|
| FunctionOverload.Binary<T1,T2> |
Helper interface for describing binary functions where the type parameters are used to improve
compile-time correctness of function bindings.
|
| FunctionOverload.Unary<T> |
Helper interface for describing unary functions where the type-parameter is used to improve
compile-time correctness of function bindings.
|
| FunctionResolver |
Interface to a resolver for CEL functions based on the function name, overload ids, and
arguments.
|
| GlobalResolver |
An interface describing an object that can perform a lookup on a given name, returning the value
associated with the so-named global variable.
|
| HomogeneousLiteralValidator |
HomogeneousLiteralValidator checks that all list and map literals entries have the same types,
i.e.
|
| ImmutableListValue<E extends CelValue> |
ImmutableListValue is a representation of an immutable list containing zero or more CelValue.
|
| ImmutableMapValue<K extends CelValue,V extends CelValue> |
MapValue is an abstract representation of an immutable map containing CelValue as keys
and values.
|
| InferenceContext |
An object holding a context for type inference.
|
| Internal |
Annotates a program element (class, method, package, etc) which is internal to CEL, not part of
the public API, and should not be used by users of CEL.
|
| Interpretable |
Represent an expression which can be interpreted repeatedly using a given activation.
|
| Interpreter |
Interface to a CEL interpreter.
|
| InterpreterException |
An exception produced during interpretation of expressions.
|
| InterpreterException.Builder |
Builder for InterpreterException.
|
| InterpreterUtil |
Util class for CEL interpreter.
|
| IntValue |
IntValue is a simple CelValue wrapper around Java longs.
|
| Latin1CodePointArray |
Represents an in-memory contiguous source of ISO-LATIN-1 code points.
|
| ListType |
Lists are a parameterized type with the parameter indicating the elemType.
|
| ListValue |
A list.
|
| ListValue<E extends CelValue> |
ListValue is an abstract representation of a generic list containing zero or more CelValue.
|
| ListValue |
A list.
|
| ListValue.Builder |
A list.
|
| ListValue.Builder |
A list.
|
| ListValueOrBuilder |
|
| ListValueOrBuilder |
|
| MapType |
Maps are a parameterized type where the two parameters supported indicate the keyType and
valueType of map entries.
|
| MapValue |
A map.
|
| MapValue<K extends CelValue,V extends CelValue> |
MapValue is an abstract representation of a generic map containing CelValue as keys and
values.
|
| MapValue |
A map.
|
| MapValue.Builder |
A map.
|
| MapValue.Builder |
A map.
|
| MapValue.Entry |
An entry in the map.
|
| MapValue.Entry |
Protobuf type cel.expr.MapValue.Entry
|
| MapValue.Entry.Builder |
An entry in the map.
|
| MapValue.Entry.Builder |
Protobuf type cel.expr.MapValue.Entry
|
| MapValue.EntryOrBuilder |
|
| MapValue.EntryOrBuilder |
|
| MapValueOrBuilder |
|
| MapValueOrBuilder |
|
| MessageFactory |
Deprecated.
|
| MessageFactory.CombinedMessageFactory |
The CombinedMessageFactory takes one or more MessageFactory instances and
attempts to create a Message.Builder instance for a given messageName by
calling each MessageFactory in the order that they are provided to the constructor.
|
| MessageProvider |
An object which allows to create and interpret messages.
|
| Metadata |
An interface which provides metadata for syntax nodes.
|
| NullableType |
Nullable types are a union type which indicate that the value is either the targetType or
SimpleType.NULL_TYPE
|
| NullValue |
NullValue represents the value 'null' of 'null_type' according to the CEL specification.
|
| OpaqueType |
An opaque type's properties may only be accessed via function calls associated with the type.
|
| OpaqueValue |
OpaqueValue is the value representation of OpaqueType.
|
| Operator |
Package-private enumeration of Common Expression Language operators.
|
| OptionalType |
OptionalType is an opaque type that that represents an optional value.
|
| OptionalValue<E extends CelValue> |
First-class support for CEL optionals.
|
| ParsedExpr |
An expression together with source information as returned by the parser.
|
| ParsedExpr |
An expression together with source information as returned by the parser.
|
| ParsedExpr.Builder |
An expression together with source information as returned by the parser.
|
| ParsedExpr.Builder |
An expression together with source information as returned by the parser.
|
| ParsedExprOrBuilder |
|
| ParsedExprOrBuilder |
|
| ProtoAdapter |
The ProtoAdapter utilities handle conversion between native Java objects which represent
CEL values and well-known protobuf counterparts.
|
| ProtoCelValueConverter |
CelValueConverter handles bidirectional conversion between native Java and protobuf
objects to CelValue.
|
| ProtoEquality |
The ProtoEquality implementation is an alternative to the Message.equals(java.lang.Object)
implementation that is consistent with the C++ MessageDifferencer::Equals definition.
|
| ProtoMessageFactory |
ProtoMessageFactory provides a method to create a protobuf builder objects by name.
|
| ProtoMessageFactory.CombinedMessageFactory |
|
| ProtoMessageType |
The ProtoMessageType is a StructType with support for proto Extensions
and field masks.
|
| ProtoMessageType.Extension |
Extension contains the name, type, and target message type of the extension.
|
| ProtoMessageTypeProvider |
The ProtoMessageTypeProvider implements the CelTypeProvider interface to provide
CelType objects for the core CEL types and a list of protobuf message types.
|
| ProtoMessageValue |
ProtoMessageValue is a struct value with protobuf support.
|
| ProtoMessageValueProvider |
ProtoMessageValueProvider constructs new instances of a protobuf message given its fully
qualified name and its fields to populate.
|
| ProtoTypeMask |
ProtoTypeMask describes the fraction of a protobuf type's object graph that should be
visible within CEL expressions.
|
| ProtoTypeMaskTypeProvider |
The ProtoTypeMaskTypeProvider binds a set of ProtoTypeMask instances to type
definitions and ensures that only fields which have been explicitly listed by the set of
ProtoTypeMask values is exposed within the CEL type system.
|
| Reference |
Describes a resolved reference to a declaration.
|
| Reference |
Describes a resolved reference to a declaration.
|
| Reference.Builder |
Describes a resolved reference to a declaration.
|
| Reference.Builder |
Describes a resolved reference to a declaration.
|
| ReferenceOrBuilder |
|
| ReferenceOrBuilder |
|
| RegexLiteralValidator |
RegexLiteralValidator ensures that regex patterns are valid.
|
| Registrar |
An object which registers the functions that a Dispatcher calls.
|
| Registrar.BinaryFunction<T1,T2> |
Helper interface for describing binary functions where the type parameters are used to improve
compile-time correctness of function bindings.
|
| Registrar.Function |
Interface describing the general signature of all CEL custom function implementations.
|
| Registrar.UnaryFunction<T> |
Helper interface for describing unary functions where the type-parameter is used to improve
compile-time correctness of function bindings.
|
| ResolvedOverload |
Representation of a function overload which has been resolved to a specific set of argument types
and a function definition.
|
| RuntimeEquality |
CEL Library Internals.
|
| RuntimeHelpers |
Helper methods for common CEL related routines.
|
| RuntimeTypeProvider |
The RuntimeTypeProvider is a combination of the MessageProvider and
TypeResolver interfaces.
|
| RuntimeTypeProviderLegacyImpl |
Bridge between the old RuntimeTypeProvider and CelValueProvider APIs.
|
| RuntimeUnknownResolver |
Runtime representation of the current state in an iterative evaluation session.
|
| RuntimeUnknownResolver.Builder |
|
| SafeStringFormatter |
SafeStringFormatter is a wrapper around JDK's String.format(java.lang.String, java.lang.Object...).
|
| SelectableValue<T extends CelValue> |
SelectableValue is an interface for representing a value that supports field selection and
presence tests.
|
| SimpleType |
Simple types represent scalar, dynamic, and error values.
|
| Source |
Common interface definition for source properties.
|
| SourceInfo |
Source information collected at parse time.
|
| SourceInfo |
Source information collected at parse time.
|
| SourceInfo.Builder |
Source information collected at parse time.
|
| SourceInfo.Builder |
Source information collected at parse time.
|
| SourceInfo.Extension |
An extension that was requested for the source expression.
|
| SourceInfo.Extension.Builder |
An extension that was requested for the source expression.
|
| SourceInfo.Extension.Component |
CEL component specifier.
|
| SourceInfo.Extension.Version |
Version
|
| SourceInfo.Extension.Version.Builder |
Version
|
| SourceInfo.Extension.VersionOrBuilder |
|
| SourceInfo.ExtensionOrBuilder |
|
| SourceInfoOrBuilder |
|
| SourceInfoOrBuilder |
|
| SourcePosition |
A specific position in source.
|
| SourcePosition.Builder |
A specific position in source.
|
| SourcePositionOrBuilder |
|
| StandardFunctions |
Deprecated.
|
| StringValue |
StringValue is a simple CelValue wrapper around Java strings.
|
| StructType |
Struct type indicates that the type name is a structured object with typed properties.
|
| StructType.Field |
Value object which holds a reference to the field name and type.
|
| StructType.FieldResolver |
The FieldResolver is used to lookup the type of a StructType's
fieldName.
|
| StructTypeReference |
A simple type reference to a struct.
|
| StructValue<T extends CelValue> |
StructValue is a representation of a structured object with typed properties.
|
| SubexpressionOptimizer |
Performs Common Subexpression Elimination.
|
| SubexpressionOptimizer.SubexpressionOptimizerOptions |
Options to configure how Common Subexpression Elimination behave.
|
| SubexpressionOptimizer.SubexpressionOptimizerOptions.Builder |
|
| SupplementalCodePointArray |
Array of code points that contain code points from Latin-1 character set, basic multilingual
plane or the supplemental multilingual plane.
|
| SyntaxProto |
|
| SyntaxProto |
|
| TimestampLiteralValidator |
TimestampLiteralValidator ensures that timestamp literal arguments are valid.
|
| TimestampValue |
TimestampValue is a simple CelValue wrapper around Instant
|
| TraversalOrder |
Specifies the traversal order of AST navigation.
|
| Type |
Represents a CEL type.
|
| Type |
Represents a CEL type.
|
| Type.AbstractType |
Application defined abstract type.
|
| Type.AbstractType |
Application defined abstract type.
|
| Type.AbstractType.Builder |
Application defined abstract type.
|
| Type.AbstractType.Builder |
Application defined abstract type.
|
| Type.AbstractTypeOrBuilder |
|
| Type.AbstractTypeOrBuilder |
|
| Type.Builder |
Represents a CEL type.
|
| Type.Builder |
Represents a CEL type.
|
| Type.FunctionType |
Function type with result and arg types.
|
| Type.FunctionType |
Function type with result and arg types.
|
| Type.FunctionType.Builder |
Function type with result and arg types.
|
| Type.FunctionType.Builder |
Function type with result and arg types.
|
| Type.FunctionTypeOrBuilder |
|
| Type.FunctionTypeOrBuilder |
|
| Type.ListType |
List type with typed elements, e.g.
|
| Type.ListType |
List type with typed elements, e.g.
|
| Type.ListType.Builder |
List type with typed elements, e.g.
|
| Type.ListType.Builder |
List type with typed elements, e.g.
|
| Type.ListTypeOrBuilder |
|
| Type.ListTypeOrBuilder |
|
| Type.MapType |
Map type with parameterized key and value types, e.g.
|
| Type.MapType |
Map type with parameterized key and value types, e.g.
|
| Type.MapType.Builder |
Map type with parameterized key and value types, e.g.
|
| Type.MapType.Builder |
Map type with parameterized key and value types, e.g.
|
| Type.MapTypeOrBuilder |
|
| Type.MapTypeOrBuilder |
|
| Type.PrimitiveType |
CEL primitive types.
|
| Type.PrimitiveType |
CEL primitive types.
|
| Type.TypeKindCase |
|
| Type.TypeKindCase |
|
| Type.WellKnownType |
Well-known protobuf types treated with first-class support in CEL.
|
| Type.WellKnownType |
Well-known protobuf types treated with first-class support in CEL.
|
| TypeFormatter |
Class to format Type objects into String values.
|
| TypeOrBuilder |
|
| TypeOrBuilder |
|
| TypeParamType |
Type parameters are 'free' types which take on a concrete type contextually.
|
| TypeProvider |
Deprecated.
|
| TypeProvider.CombinedTypeProvider |
The CombinedTypeProvider takes one or more TypeProvider instances and attempts
to look up a Type instance for a given typeName by calling each
TypeProvider in the order that they are provided to the constructor.
|
| TypeProvider.ExtensionFieldType |
|
| TypeProvider.FieldType |
|
| Types |
Utilities for dealing with the Type proto.
|
| TypeType |
The TypeType is a type which holds a reference to a type-kind.
|
| TypeValue |
TypeValue holds the CEL type information for the underlying CelValue.
|
| UintValue |
UintValue represents CelValue for unsigned longs.
|
| UnknownContext |
AsyncContext represents the state required for an iterative evaluation session in the CEL
evaluator.
|
| UnknownSet |
A set of expressions for which the value is unknown.
|
| UnknownSet |
A set of expressions for which the value is unknown.
|
| UnknownSet.Builder |
A set of expressions for which the value is unknown.
|
| UnknownSet.Builder |
A set of expressions for which the value is unknown.
|
| UnknownSetOrBuilder |
|
| UnknownSetOrBuilder |
|
| UnknownTrackingInterpretable |
An interpretable that allows for tracking unknowns at runtime.
|
| UnspecifiedType |
Represents an unspecified CEL-Type.
|
| Value |
Represents a CEL value.
|
| Value |
Represents a CEL value.
|
| Value.Builder |
Represents a CEL value.
|
| Value.Builder |
Represents a CEL value.
|
| Value.KindCase |
|
| Value.KindCase |
|
| ValueOrBuilder |
|
| ValueOrBuilder |
|
| ValueProto |
|
| ValueProto |
|
| WellKnownProto |
WellKnownProto types used throughout CEL.
|