Class CelEnvironment.ExtensionConfig

  • Enclosing class:
    CelEnvironment

    public abstract static class CelEnvironment.ExtensionConfig
    extends java.lang.Object
    Represents a configuration for a canonical CEL extension that can be enabled in the environment.
    • Constructor Detail

      • ExtensionConfig

        public ExtensionConfig()
    • Method Detail

      • name

        public abstract java.lang.String name()
        Name of the extension (ex: bindings, optional, math, etc).".
      • version

        public abstract int version()
        Version of the extension. Presently, this field is ignored as CEL-Java extensions are not versioned.
      • of

        public static CelEnvironment.ExtensionConfig of​(java.lang.String name)
        Create a new extension config with the specified name and version set to 0.
      • of

        public static CelEnvironment.ExtensionConfig of​(java.lang.String name,
                                                        int version)
        Create a new extension config with the specified name and version.
      • latest

        public static CelEnvironment.ExtensionConfig latest​(java.lang.String name)
        Create a new extension config with the specified name and the latest version.