Class CelMutableAst


  • public final class CelMutableAst
    extends java.lang.Object
    An abstract representation of CEL Abstract Syntax tree that allows mutation in any of its properties. This class is semantically the same as that of the immutable CelAbstractSyntaxTree.

    This should only be used within optimizers to augment an AST.