Package dev.cel.common.ast
Class CelMutableExpr.CelMutableList
- java.lang.Object
-
- dev.cel.common.ast.CelMutableExpr.CelMutableList
-
- All Implemented Interfaces:
Expression.List<CelMutableExpr>
- Enclosing class:
- CelMutableExpr
public static final class CelMutableExpr.CelMutableList extends java.lang.Object implements Expression.List<CelMutableExpr>
A mutable list creation expression. SeeExpression.List
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static CelMutableExpr.CelMutableListcreate(CelMutableExpr... elements)static CelMutableExpr.CelMutableListcreate(java.util.List<CelMutableExpr> elements)static CelMutableExpr.CelMutableListcreate(java.util.List<CelMutableExpr> mutableExprList, java.util.List<java.lang.Integer> optionalIndices)java.util.List<CelMutableExpr>elements()The elements part of the listbooleanequals(java.lang.Object obj)inthashCode()java.util.List<java.lang.Integer>optionalIndices()The indices within the elements list which are marked as optional elements.voidsetElement(int index, CelMutableExpr element)
-
-
-
Method Detail
-
elements
public java.util.List<CelMutableExpr> elements()
Description copied from interface:Expression.ListThe elements part of the list- Specified by:
elementsin interfaceExpression.List<CelMutableExpr>
-
setElement
public void setElement(int index, CelMutableExpr element)
-
optionalIndices
public java.util.List<java.lang.Integer> optionalIndices()
Description copied from interface:Expression.ListThe indices within the elements list which are marked as optional elements.When an optional-typed value is present, the value it contains is included in the list. If the optional-typed value is absent, the list element is omitted from the list result.
- Specified by:
optionalIndicesin interfaceExpression.List<CelMutableExpr>
-
equals
public boolean equals(java.lang.Object obj)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
create
public static CelMutableExpr.CelMutableList create(CelMutableExpr... elements)
-
create
public static CelMutableExpr.CelMutableList create(java.util.List<CelMutableExpr> elements)
-
create
public static CelMutableExpr.CelMutableList create(java.util.List<CelMutableExpr> mutableExprList, java.util.List<java.lang.Integer> optionalIndices)
-
-