Package dev.cel.extensions
Enum CelListsExtensions.Function
- java.lang.Object
-
- java.lang.Enum<CelListsExtensions.Function>
-
- dev.cel.extensions.CelListsExtensions.Function
-
- All Implemented Interfaces:
java.io.Serializable,java.lang.Comparable<CelListsExtensions.Function>
- Enclosing class:
- CelListsExtensions
public static enum CelListsExtensions.Function extends java.lang.Enum<CelListsExtensions.Function>
Supported functions for Lists extension library.
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static CelListsExtensions.FunctionvalueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static CelListsExtensions.Function[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
SLICE
public static final CelListsExtensions.Function SLICE
-
FLATTEN
public static final CelListsExtensions.Function FLATTEN
-
RANGE
public static final CelListsExtensions.Function RANGE
-
DISTINCT
public static final CelListsExtensions.Function DISTINCT
-
REVERSE
public static final CelListsExtensions.Function REVERSE
-
SORT
public static final CelListsExtensions.Function SORT
-
SORT_BY
public static final CelListsExtensions.Function SORT_BY
-
-
Method Detail
-
values
public static CelListsExtensions.Function[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (CelListsExtensions.Function c : CelListsExtensions.Function.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static CelListsExtensions.Function valueOf(java.lang.String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
java.lang.IllegalArgumentException- if this enum type has no constant with the specified namejava.lang.NullPointerException- if the argument is null
-
-