Class CelOptionalLibrary

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      static class  CelOptionalLibrary.Function
      Enumerations of function names used for supporting optionals.
    • Method Summary

      All Methods Instance Methods Concrete Methods 
      Modifier and Type Method Description
      void setCheckerOptions​(CelCheckerBuilder checkerBuilder)
      Configures the checker to support the library implementation, such as adding function bindings
      void setParserOptions​(CelParserBuilder parserBuilder)
      Configures the parser to support the library implementation, such as adding macros
      void setRuntimeOptions​(CelRuntimeBuilder runtimeBuilder)
      Configures the runtime to support the library implementation, such as adding function bindings.
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait