Package dev.cel.bundle
Class CelEnvironment.ExtensionConfig
- java.lang.Object
-
- dev.cel.bundle.CelEnvironment.ExtensionConfig
-
- Enclosing class:
- CelEnvironment
public abstract static class CelEnvironment.ExtensionConfig extends java.lang.ObjectRepresents a configuration for a canonical CEL extension that can be enabled in the environment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classCelEnvironment.ExtensionConfig.BuilderBuilder forCelEnvironment.ExtensionConfig.
-
Constructor Summary
Constructors Constructor Description ExtensionConfig()
-
Method Summary
All Methods Static Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description static CelEnvironment.ExtensionConfiglatest(java.lang.String name)Create a new extension config with the specified name and the latest version.abstract java.lang.Stringname()Name of the extension (ex: bindings, optional, math, etc).".static CelEnvironment.ExtensionConfig.BuildernewBuilder()Creates a new builder to construct aCelEnvironment.ExtensionConfiginstance.static CelEnvironment.ExtensionConfigof(java.lang.String name)Create a new extension config with the specified name and version set to 0.static CelEnvironment.ExtensionConfigof(java.lang.String name, int version)Create a new extension config with the specified name and version.abstract intversion()Version of the extension.
-
-
-
Method Detail
-
name
public abstract java.lang.String name()
Name of the extension (ex: bindings, optional, math, etc).".
-
version
public abstract int version()
Version of the extension. Presently, this field is ignored as CEL-Java extensions are not versioned.
-
newBuilder
public static CelEnvironment.ExtensionConfig.Builder newBuilder()
Creates a new builder to construct aCelEnvironment.ExtensionConfiginstance.
-
of
public static CelEnvironment.ExtensionConfig of(java.lang.String name)
Create a new extension config with the specified name and version set to 0.
-
of
public static CelEnvironment.ExtensionConfig of(java.lang.String name, int version)
Create a new extension config with the specified name and version.
-
latest
public static CelEnvironment.ExtensionConfig latest(java.lang.String name)
Create a new extension config with the specified name and the latest version.
-
-