Package dev.cel.extensions
Class CelOptionalLibrary
- java.lang.Object
-
- dev.cel.extensions.CelOptionalLibrary
-
- All Implemented Interfaces:
CelCheckerLibrary,CelCompilerLibrary,CelParserLibrary,CelRuntimeLibrary
public final class CelOptionalLibrary extends java.lang.Object implements CelCompilerLibrary, CelRuntimeLibrary
Internal implementation of CEL optional values.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classCelOptionalLibrary.FunctionEnumerations of function names used for supporting optionals.
-
Field Summary
Fields Modifier and Type Field Description static CelOptionalLibraryINSTANCE
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidsetCheckerOptions(CelCheckerBuilder checkerBuilder)Configures the checker to support the library implementation, such as adding function bindingsvoidsetParserOptions(CelParserBuilder parserBuilder)Configures the parser to support the library implementation, such as adding macrosvoidsetRuntimeOptions(CelRuntimeBuilder runtimeBuilder)Configures the runtime to support the library implementation, such as adding function bindings.
-
-
-
Field Detail
-
INSTANCE
public static final CelOptionalLibrary INSTANCE
-
-
Method Detail
-
setParserOptions
public void setParserOptions(CelParserBuilder parserBuilder)
Description copied from interface:CelParserLibraryConfigures the parser to support the library implementation, such as adding macros- Specified by:
setParserOptionsin interfaceCelParserLibrary
-
setCheckerOptions
public void setCheckerOptions(CelCheckerBuilder checkerBuilder)
Description copied from interface:CelCheckerLibraryConfigures the checker to support the library implementation, such as adding function bindings- Specified by:
setCheckerOptionsin interfaceCelCheckerLibrary
-
setRuntimeOptions
public void setRuntimeOptions(CelRuntimeBuilder runtimeBuilder)
Description copied from interface:CelRuntimeLibraryConfigures the runtime to support the library implementation, such as adding function bindings.- Specified by:
setRuntimeOptionsin interfaceCelRuntimeLibrary
-
-